GoScale CMS documentation — goscalecms 0.5.2 documentation

# GoScale CMS documentation

GoScale CMS is an extension of Django CMS.

It’s a set of unique plugins and useful tools for Django CMS that makes it very powerful by seamlessly integrating content from 3rd party websites like:

- Blogger and Tumblr
- Youtube and Vimeo
- Picasa and Google+
- Google Calendar and Forms
- Any RSS/Atom feeds

But it’s more than just content. GoScale plugins add some fancy functionality to make this content shine!

It’s perfect for quickly building Mashups and Media heavy sites.

GoScale CMS is a product of Sterno.Ru.

Website: http://goscalecms.com

GitHub repository: https://github.com/sternoru/goscalecms

Google Group: https://groups.google.com/forum/?fromgroups#!forum/goscale-cms

## Installation

- 1. Getting started
  - 1.1. Requirements
  - 1.2. Installation

## Usage

- 1. Available plugins
  - 1.1. Calendar
  - 1.2. Feed
  - 1.3. Blogger and Tumblr
  - 1.4. Form
  - 1.5. Picasa
  - 1.6. YouKu
  - 1.7. Google Presentation
  - 1.8. Slideshare Presentation
  - 1.9. Speakerdeck Presentation
- 2. Configuration
  - 2.1. Plugins settings
  - 2.2. Global settings
  - 2.3. Theme settings
- 3. Management commands
  - 3.1. update_slugs
  - 3.1. update_posts
- 4. Celery tasks
  - 4.1. update_goscale_plugins
  - 4.2. update_goscale_plugin_posts

## Advanced

- 1. Template tags
  - 1.1. Paginator
  - 1.2. Plugin filters
  - 1.3. Plugin post
  - 1.4. GoScale Placeholder
  - 1.5. GoScale AddtoBlock
  - 1.6. User
  - 1.7. Login
- 2. Plugins front-end
  - 2.1. Templates
  - 2.2. Static files
  - 2.3. Ajaxlinks
- 3. Themes support
  - 3.1. Installation
  - 3.2. Usage
  - 3.3. Using theme files in templates
  - 3.4. Theme switching on request
  - 3.5. Debugging theme switching
- 4. Authorization and registration
  - 4.1. Installation
  - 4.2. Usage

# Indices and tables

- Index
- Module Index
- Search Page